//
//  CreateSubChannelView.swift
//  SampleApp
//
//  Created by Amity on 7/11/2565 BE.
//  Copyright © 2565 BE David Zhang. All rights reserved.
//

import Foundation
import SwiftUI
import AmitySDK

/// Creates subchannel & shows successfully created subchannels on list
struct CreateSubChannelView: View {
    
    @State var channelId: String = ""
    @State private var subchannelName: String = ""
    
    // Alert
    @State private var isAlertShown = false
    @State private var alertMessage: String = ""
    
    @StateObject var viewModel = SubChannelManager()
    
    @State private var subchannels = [AmitySubChannel]()

    var body: some View {
        VStack(alignment: .leading, spacing: 0) {
            
            Text("Channel Id:")
                .font(.footnote)
                .foregroundColor(.secondary)
                .padding(.bottom, 4)
            
            TextField("Enter channel Id", text: $channelId)
                .modifier(AmityTextFieldStyle())
                .keyboardType(.default)
                .autocapitalization(.none)
            
            Text("Note: Use channel internal id for testing")
                .font(.footnote)
                .foregroundColor(.secondary)
                .padding(.top, 4)
            
            TextField("Sub Channel Name", text: $subchannelName)
                .modifier(AmityTextFieldStyle())
                .padding(.top, 16)
            
            AmityDefaultButton(title: "Create") {
                // Create subchannels
                viewModel.createSubChannel(channelId: channelId, displayName: subchannelName) { subchannel, error in
                    
                    if let error {
                        alertMessage = error.localizedDescription
                    } else {
                        alertMessage = "SubChannel created successfully!"
                        
                        if let subchannel {
                            subchannels = [subchannel]
                        }
                    }
                    
                    // Show alert
                    isAlertShown.toggle()
                }
            }
            .padding(.top, 16)
            
            Divider()
                .frame(width: 100)
                .padding(.vertical, 16)
            
            List(subchannels, id: \.subChannelId) { item in
                VStack(alignment: .leading) {
                    Text(item.displayName)
                        .font(.headline)
                        .padding(.bottom, 4)
                    Text("Id: \(item.subChannelId)")
                    Text("Channel Id: \(item.channelId)")
                    Text("Deleted: \(item.isDeleted ? "True" : "False")")
                }
                .onTapGesture {
                    UIPasteboard.general.string = item.subChannelId
                    
                    alertMessage = "Sub channel id copied!"
                }
            }
            .listStyle(.plain)
        }
        .padding()
        .alert(isPresented: $isAlertShown) {
            Alert(title: Text(""), message: Text(alertMessage), dismissButton: .cancel(Text("Dismiss")))
        }
    }
}

struct CreateSubChannelView_Previews: PreviewProvider {
    
    static var previews: some View {
        CreateSubChannelView()
    }
}
