//
//  PostFlagManager.swift
//  SampleApp
//
//  Created by Nishan Niraula on 10/5/20.
//  Copyright © 2020 David Zhang. All rights reserved.
//

import Foundation
import AmitySDK

class PostFlagManager {
    
    let postRepository: AmityPostRepository = AmityPostRepository(client: AmityManager.shared.client!)
    
    func flagPost(post: AmityPost?, completion:@escaping (_ isSuccess: Bool, _ error: Error?)->()) {
        
        guard let post = post else { return }
        
        Task { @MainActor in
            
            do {
                let result = try await postRepository.flagPost(withId: post.postId)
                Log.add(info: "Post Flag \(result)")
                completion(result, nil)
            } catch {
                Log.add(info: "Post Flag with error \(String(describing: error))")
                completion(false, error)
            }
        }
    }
    
    func unflagPost(post: AmityPost?, completion:@escaping (_ isSuccess: Bool, _ error: Error?)->()) {
        
        guard let post = post else { return }
        
        Task { @MainActor in
            do {
                let result = try await postRepository.unflagPost(withId: post.postId)
                Log.add(info: "Post UnFlag \(result)")
                completion(result, nil)
            } catch {
                Log.add(info: "Post UnFlag with error \(String(describing: error))")
                completion(false, error)
            }
        }
    }
    
    func isPostFlaggedByMe(post: AmityPost?, completion:@escaping (_ isFlagged: Bool) -> ()) {
        
        guard let post = post else { return }
        
        Task { @MainActor in
            do {
                let result = try await postRepository.isFlaggedByMe(withId: post.postId)
                completion(result)
            } catch {
                completion(false)
            }
        }
    }
}
